==> haskell-ghc-check-0.5.0.8-145.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-check.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-check
version:              0.5.0.8
visibility:           public
id:                   ghc-check-0.5.0.8-ArWCdX3lBLiC75JtLiDFT0
key:                  ghc-check-0.5.0.8-ArWCdX3lBLiC75JtLiDFT0
license:              BSD-3-Clause
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:
    detect mismatches between compile-time and run-time versions of the ghc api

description:
    detect mismatches between compile-time and run-time versions of the ghc api

category:             Development
abi:                  4e5c9630b7db0676282f2057319f030b
exposed:              True
exposed-modules:      GHC.Check GHC.Check.Executable GHC.Check.PackageDb
hidden-modules:       GHC.Check.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghc-check-0.5.0.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghc-check-0.5.0.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghc-check-0.5.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-check
hs-libraries:         HSghc-check-0.5.0.8-ArWCdX3lBLiC75JtLiDFT0
depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5 filepath-1.4.300.1
    ghc-9.6.6 ghc-boot-9.6.6 ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    process-1.6.19.0 safe-exceptions-0.1.7.4-77vNmGqKu2OFQzf0vTZZHI
    template-haskell-2.20.0.0 th-compat-0.1.6-GpjIKGc0GPMFBEveh1mM8h
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-ghc-check/html/ghc-check.haddock
haddock-html:         /usr/share/doc/haskell-ghc-check/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-check-0.5.0.8-146-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-check.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-check
version:              0.5.0.8
visibility:           public
id:                   ghc-check-0.5.0.8-EfwdDqh52DcE1vfSzPB33A
key:                  ghc-check-0.5.0.8-EfwdDqh52DcE1vfSzPB33A
license:              BSD-3-Clause
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:
    detect mismatches between compile-time and run-time versions of the ghc api

description:
    detect mismatches between compile-time and run-time versions of the ghc api

category:             Development
abi:                  68421eeaf7dbffbec32ba70863b8ddc9
exposed:              True
exposed-modules:      GHC.Check GHC.Check.Executable GHC.Check.PackageDb
hidden-modules:       GHC.Check.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghc-check-0.5.0.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghc-check-0.5.0.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghc-check-0.5.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-check
hs-libraries:         HSghc-check-0.5.0.8-EfwdDqh52DcE1vfSzPB33A
depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5 filepath-1.4.300.1
    ghc-9.6.6 ghc-boot-9.6.6 ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    process-1.6.19.0 safe-exceptions-0.1.7.4-77vNmGqKu2OFQzf0vTZZHI
    template-haskell-2.20.0.0 th-compat-0.1.6-KectvLb9yylAlpm8iQXOj
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-ghc-check/html/ghc-check.haddock
haddock-html:         /usr/share/doc/haskell-ghc-check/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
